# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class NumbersEFT(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'account': 'str',
        'institution': 'str',
        'branch': 'str'
    }

    attribute_map = {
        'account_id': 'account_id',
        'account': 'account',
        'institution': 'institution',
        'branch': 'branch'
    }

    def __init__(self, account_id=None, account=None, institution=None, branch=None, local_vars_configuration=None):  # noqa: E501
        """NumbersEFT - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._account = None
        self._institution = None
        self._branch = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if account is not None:
            self.account = account
        if institution is not None:
            self.institution = institution
        if branch is not None:
            self.branch = branch

    @property
    def account_id(self):
        """Gets the account_id of this NumbersEFT.  # noqa: E501

        The Plaid account ID associated with the account numbers  # noqa: E501

        :return: The account_id of this NumbersEFT.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this NumbersEFT.

        The Plaid account ID associated with the account numbers  # noqa: E501

        :param account_id: The account_id of this NumbersEFT.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def account(self):
        """Gets the account of this NumbersEFT.  # noqa: E501

        The EFT account number for the account  # noqa: E501

        :return: The account of this NumbersEFT.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this NumbersEFT.

        The EFT account number for the account  # noqa: E501

        :param account: The account of this NumbersEFT.  # noqa: E501
        :type account: str
        """

        self._account = account

    @property
    def institution(self):
        """Gets the institution of this NumbersEFT.  # noqa: E501

        The EFT institution number for the account  # noqa: E501

        :return: The institution of this NumbersEFT.  # noqa: E501
        :rtype: str
        """
        return self._institution

    @institution.setter
    def institution(self, institution):
        """Sets the institution of this NumbersEFT.

        The EFT institution number for the account  # noqa: E501

        :param institution: The institution of this NumbersEFT.  # noqa: E501
        :type institution: str
        """

        self._institution = institution

    @property
    def branch(self):
        """Gets the branch of this NumbersEFT.  # noqa: E501

        The EFT branch number for the account  # noqa: E501

        :return: The branch of this NumbersEFT.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this NumbersEFT.

        The EFT branch number for the account  # noqa: E501

        :param branch: The branch of this NumbersEFT.  # noqa: E501
        :type branch: str
        """

        self._branch = branch

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NumbersEFT):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NumbersEFT):
            return True

        return self.to_dict() != other.to_dict()
