# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class LinkTokenCreateResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'link_token': 'str',
        'expiration': 'str'
    }

    attribute_map = {
        'link_token': 'link_token',
        'expiration': 'expiration'
    }

    def __init__(self, link_token=None, expiration=None, local_vars_configuration=None):  # noqa: E501
        """LinkTokenCreateResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._link_token = None
        self._expiration = None
        self.discriminator = None

        if link_token is not None:
            self.link_token = link_token
        if expiration is not None:
            self.expiration = expiration

    @property
    def link_token(self):
        """Gets the link_token of this LinkTokenCreateResponse.  # noqa: E501

        A `link_token`, which can be supplied to Link in order to initialize it and receive a `public_token`, which can be exchanged for an `access_token`.  # noqa: E501

        :return: The link_token of this LinkTokenCreateResponse.  # noqa: E501
        :rtype: str
        """
        return self._link_token

    @link_token.setter
    def link_token(self, link_token):
        """Sets the link_token of this LinkTokenCreateResponse.

        A `link_token`, which can be supplied to Link in order to initialize it and receive a `public_token`, which can be exchanged for an `access_token`.  # noqa: E501

        :param link_token: The link_token of this LinkTokenCreateResponse.  # noqa: E501
        :type link_token: str
        """

        self._link_token = link_token

    @property
    def expiration(self):
        """Gets the expiration of this LinkTokenCreateResponse.  # noqa: E501

        The expiration date for the `link_token`, in ISO 8601 format. A `link_token` created to generate a `public_token` that will be exchanged for a new `access_token` expires after 24 hours. A `link_token` created for an existing Item (such as when updating an existing `access_token` by launching Link in update mode) expires after 30 minutes.  # noqa: E501

        :return: The expiration of this LinkTokenCreateResponse.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this LinkTokenCreateResponse.

        The expiration date for the `link_token`, in ISO 8601 format. A `link_token` created to generate a `public_token` that will be exchanged for a new `access_token` expires after 24 hours. A `link_token` created for an existing Item (such as when updating an existing `access_token` by launching Link in update mode) expires after 30 minutes.  # noqa: E501

        :param expiration: The expiration of this LinkTokenCreateResponse.  # noqa: E501
        :type expiration: str
        """

        self._expiration = expiration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LinkTokenCreateResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LinkTokenCreateResponse):
            return True

        return self.to_dict() != other.to_dict()
